==> open-xchange-guard_2.6.0.orig.tar.bz2: open-xchange-guard-2.6.0/com.openexchange.guard.antiabuse/src/com/openexchange/guard/antiabuse/GuardAntiAbuseService.java <==
package com.openexchange.guard.antiabuse;

import com.openexchange.exception.OXException;
import com.openexchange.guard.antiabuse.bad.Bad;

public interface GuardAntiAbuseService {

    /**
     * Gets the bad login attempts for a given id/session
     *
     * @param id the session to the get the attempts for
     * @return the bad login attempts for the given id
     * @throws OXException due an error
     */
    public Bad getBad(String id) throws OXException;

    /**
     * Adds a bad login attempt for a given id/session
     *
     * @param id the session to add the bad login attempt for
     * @throws OXException due an error
     */
    public void addBad(String id) throws OXException;

    /**
     * Removes all bad login attempts for a given session
     *
     * @param id the session to remove the bad login attempts for
     * @throws OXException due an error
     */
    public void removeBad(String id) throws OXException;

    /**
     * Check if id is listed as bad.
     *
     * @param id Could be IP, itemID, or session
     * @param threshold Number of bad tries within time period acceptable
     * @return true, if the ID has been listed as bad, false otherwise
     * @throws OXException
     */
    boolean isBad(String id, int threshold) throws OXException;

    /**
     * Check if id is listed as bad while using the default threshold from configuration
     * @param id id could be IP, itemID or session
     * @return true, if the ID has been listed as bad, false otherwise
     * @throws OXExcpetion
     */
    boolean isBad(String id) throws OXException;

    /**
     * Check if login should be allowed
     * @param username
     * @param password
     * @param ip
     * @return
     * @throws OXException
     */
    boolean allowLogin (String username, String password, String ip) throws OXException;

    /**
     * Check if login should be allowed
     * @param userid
     * @param cid
     * @param password
     * @param ip
     * @return
     * @throws OXException
     */
    boolean allowLogin (int userid, int cid, String password, String ip) throws OXException;

    /**
     * Check if the login should be blocked
     * @param userid
     * @param cid
     * @param password
     * @param ip
     * @return
     * @throws OXException
     */
    boolean blockLogin (int userid, int cid, String password, String ip) throws OXException;

    /**
     * Check if the login should be blocked.  Inverse of allowLogin
     * @param userid
     * @param cid
     * @param password
     * @param ip
     * @return
     * @throws OXException
     */
    boolean blockLogin (String username, String password, String ip) throws OXException;

    /**
     * Report login success or fail.  Inverse of allowLogin
     * @param success
     * @param username
     * @param password
     * @param ip
     * @return
     * @throws OXException
     */
    void reportLogin (boolean success, String username, String password, String ip) throws OXException;

    /**
     * Report login success or fail
     * @param success
     * @param userid
     * @param cid
     * @param password
     * @param ip
     * @return
     * @throws OXException
     */
    void reportLogin (boolean success, int userid, int cid, String password, String ip) throws OXException;
}

==> open-xchange-guard_2.10.6.orig.tar.bz2: open-xchange-guard-2.10.6/com.openexchange.guard.antiabuse/src/com/openexchange/guard/antiabuse/GuardAntiAbuseService.java <==
package com.openexchange.guard.antiabuse;

import com.openexchange.antiabuse.AllowParameters;
import com.openexchange.antiabuse.ReportParameters;
import com.openexchange.exception.OXException;
import com.openexchange.guard.antiabuse.bad.Bad;

public interface GuardAntiAbuseService {

    /**
     * Gets the bad login attempts for a given id/session
     *
     * @param id the session to the get the attempts for
     * @return the bad login attempts for the given id
     * @throws OXException due an error
     */
    public Bad getBad(String id) throws OXException;

    /**
     * Adds a bad login attempt for a given id/session
     *
     * @param id the session to add the bad login attempt for
     * @throws OXException due an error
     */
    public void addBad(String id) throws OXException;

    /**
     * Removes all bad login attempts for a given session
     *
     * @param id the session to remove the bad login attempts for
     * @throws OXException due an error
     */
    public void removeBad(String id) throws OXException;

    /**
     * Check if id is listed as bad.
     *
     * @param id Could be IP, itemID, or session
     * @param threshold Number of bad tries within time period acceptable
     * @return true, if the ID has been listed as bad, false otherwise
     * @throws OXException
     */
    boolean isBad(String id, int threshold) throws OXException;

    /**
     * Check if id is listed as bad while using the default threshold from configuration
     * @param id id could be IP, itemID or session
     * @return true, if the ID has been listed as bad, false otherwise
     * @throws OXExcpetion
     */
    boolean isBad(String id) throws OXException;

    /**
     * Check if login should be allowed
     * @param userid
     * @param cid
     * @param password
     * @param ip
     * @return
     * @throws OXException
     */
    boolean allowLogin (AllowParameters allowParam) throws OXException;

    /**
     * Check if the login should be blocked
     * @param userid
     * @param cid
     * @param password
     * @param ip
     * @return
     * @throws OXException
     */
    boolean blockLogin (AllowParameters allowParam) throws OXException;


    /**
     * Report login success or fail.  Inverse of allowLogin
     * @param ReportParameters
     * @return
     * @throws OXException
     */

    void report (ReportParameters reportParams) throws OXException;

}
